# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui_pyqtgraph_rev2.ui'
#
# Created by: PyQt5 UI code generator 5.11.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1024, 768)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.view_tab = QtWidgets.QTabWidget(self.centralwidget)
        self.view_tab.setGeometry(QtCore.QRect(290, 10, 691, 531))
        self.view_tab.setObjectName("view_tab")
        self.camara_tab = QtWidgets.QWidget()
        self.camara_tab.setObjectName("camara_tab")
        self.lb_photo = QtWidgets.QLabel(self.camara_tab)
        self.lb_photo.setGeometry(QtCore.QRect(10, 10, 661, 391))
        self.lb_photo.setObjectName("lb_photo")
        self.horizontalLayoutWidget_2 = QtWidgets.QWidget(self.camara_tab)
        self.horizontalLayoutWidget_2.setGeometry(QtCore.QRect(10, 460, 211, 41))
        self.horizontalLayoutWidget_2.setObjectName("horizontalLayoutWidget_2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget_2)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.lb_select_cam = QtWidgets.QLabel(self.horizontalLayoutWidget_2)
        self.lb_select_cam.setObjectName("lb_select_cam")
        self.horizontalLayout_2.addWidget(self.lb_select_cam)
        self.bt_cam = QtWidgets.QComboBox(self.horizontalLayoutWidget_2)
        self.bt_cam.setObjectName("bt_cam")
        self.bt_cam.addItem("")
        self.bt_cam.addItem("")
        self.horizontalLayout_2.addWidget(self.bt_cam)
        self.horizontalLayoutWidget_3 = QtWidgets.QWidget(self.camara_tab)
        self.horizontalLayoutWidget_3.setGeometry(QtCore.QRect(410, 460, 271, 41))
        self.horizontalLayoutWidget_3.setObjectName("horizontalLayoutWidget_3")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget_3)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.bt_cam_start = QtWidgets.QPushButton(self.horizontalLayoutWidget_3)
        self.bt_cam_start.setObjectName("bt_cam_start")
        self.horizontalLayout_3.addWidget(self.bt_cam_start)
        self.bt_cam_stop = QtWidgets.QPushButton(self.horizontalLayoutWidget_3)
        self.bt_cam_stop.setObjectName("bt_cam_stop")
        self.horizontalLayout_3.addWidget(self.bt_cam_stop)
        self.view_tab.addTab(self.camara_tab, "")
        self.plot_tab = QtWidgets.QWidget()
        self.plot_tab.setObjectName("plot_tab")
        self.plot_widget = GraphicsLayoutWidget(self.plot_tab)
        self.plot_widget.setGeometry(QtCore.QRect(10, 10, 661, 451))
        self.plot_widget.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.plot_widget.setObjectName("plot_widget")
        self.horizontalLayoutWidget = QtWidgets.QWidget(self.plot_tab)
        self.horizontalLayoutWidget.setGeometry(QtCore.QRect(10, 470, 651, 31))
        self.horizontalLayoutWidget.setObjectName("horizontalLayoutWidget")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.lb_thers_set = QtWidgets.QLabel(self.horizontalLayoutWidget)
        self.lb_thers_set.setObjectName("lb_thers_set")
        self.horizontalLayout.addWidget(self.lb_thers_set)
        self.bt_thers_set = QtWidgets.QComboBox(self.horizontalLayoutWidget)
        self.bt_thers_set.setObjectName("bt_thers_set")
        self.bt_thers_set.addItem("")
        self.bt_thers_set.addItem("")
        self.bt_thers_set.addItem("")
        self.bt_thers_set.addItem("")
        self.bt_thers_set.addItem("")
        self.bt_thers_set.addItem("")
        self.bt_thers_set.addItem("")
        self.bt_thers_set.addItem("")
        self.bt_thers_set.addItem("")
        self.horizontalLayout.addWidget(self.bt_thers_set)
        self.bt_start_draw = QtWidgets.QPushButton(self.horizontalLayoutWidget)
        self.bt_start_draw.setObjectName("bt_start_draw")
        self.horizontalLayout.addWidget(self.bt_start_draw)
        self.bt_stop_draw = QtWidgets.QPushButton(self.horizontalLayoutWidget)
        self.bt_stop_draw.setObjectName("bt_stop_draw")
        self.horizontalLayout.addWidget(self.bt_stop_draw)
        self.bt_save_data = QtWidgets.QPushButton(self.horizontalLayoutWidget)
        self.bt_save_data.setObjectName("bt_save_data")
        self.horizontalLayout.addWidget(self.bt_save_data)
        self.view_tab.addTab(self.plot_tab, "")
        self.groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox.setGeometry(QtCore.QRect(10, 10, 271, 191))
        self.groupBox.setObjectName("groupBox")
        self.gridLayoutWidget_2 = QtWidgets.QWidget(self.groupBox)
        self.gridLayoutWidget_2.setGeometry(QtCore.QRect(10, 20, 251, 161))
        self.gridLayoutWidget_2.setObjectName("gridLayoutWidget_2")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.gridLayoutWidget_2)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.s1_lb_3 = QtWidgets.QLabel(self.gridLayoutWidget_2)
        self.s1_lb_3.setObjectName("s1_lb_3")
        self.gridLayout_2.addWidget(self.s1_lb_3, 2, 0, 1, 2)
        self.s1_lb_2 = QtWidgets.QLabel(self.gridLayoutWidget_2)
        self.s1_lb_2.setObjectName("s1_lb_2")
        self.gridLayout_2.addWidget(self.s1_lb_2, 1, 0, 1, 1)
        self.s1_lb_4 = QtWidgets.QLabel(self.gridLayoutWidget_2)
        self.s1_lb_4.setObjectName("s1_lb_4")
        self.gridLayout_2.addWidget(self.s1_lb_4, 3, 0, 1, 1)
        self.s1_lb_1 = QtWidgets.QLabel(self.gridLayoutWidget_2)
        self.s1_lb_1.setObjectName("s1_lb_1")
        self.gridLayout_2.addWidget(self.s1_lb_1, 0, 0, 1, 1)
        self.s1_bt_1 = QtWidgets.QPushButton(self.gridLayoutWidget_2)
        self.s1_bt_1.setObjectName("s1_bt_1")
        self.gridLayout_2.addWidget(self.s1_bt_1, 0, 1, 1, 1)
        self.s1_bt_5 = QtWidgets.QPushButton(self.gridLayoutWidget_2)
        self.s1_bt_5.setObjectName("s1_bt_5")
        self.gridLayout_2.addWidget(self.s1_bt_5, 4, 0, 1, 1)
        self.s1_bt_6 = QtWidgets.QPushButton(self.gridLayoutWidget_2)
        self.s1_bt_6.setObjectName("s1_bt_6")
        self.gridLayout_2.addWidget(self.s1_bt_6, 4, 1, 1, 1)
        self.s1_bt_2 = QtWidgets.QComboBox(self.gridLayoutWidget_2)
        self.s1_bt_2.setObjectName("s1_bt_2")
        self.gridLayout_2.addWidget(self.s1_bt_2, 1, 1, 1, 1)
        self.s1_bt_4 = QtWidgets.QComboBox(self.gridLayoutWidget_2)
        self.s1_bt_4.setObjectName("s1_bt_4")
        self.s1_bt_4.addItem("")
        self.s1_bt_4.addItem("")
        self.s1_bt_4.addItem("")
        self.gridLayout_2.addWidget(self.s1_bt_4, 3, 1, 1, 1)
        self.groupBox_2 = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox_2.setGeometry(QtCore.QRect(10, 210, 271, 331))
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayoutWidget_3 = QtWidgets.QWidget(self.groupBox_2)
        self.gridLayoutWidget_3.setGeometry(QtCore.QRect(10, 20, 251, 301))
        self.gridLayoutWidget_3.setObjectName("gridLayoutWidget_3")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.gridLayoutWidget_3)
        self.gridLayout_3.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.s2_lb_2 = QtWidgets.QLabel(self.gridLayoutWidget_3)
        self.s2_lb_2.setObjectName("s2_lb_2")
        self.gridLayout_3.addWidget(self.s2_lb_2, 1, 0, 1, 1)
        self.s2_di_1 = QtWidgets.QDial(self.gridLayoutWidget_3)
        self.s2_di_1.setMaximum(9)
        self.s2_di_1.setPageStep(1)
        self.s2_di_1.setWrapping(False)
        self.s2_di_1.setNotchesVisible(True)
        self.s2_di_1.setObjectName("s2_di_1")
        self.gridLayout_3.addWidget(self.s2_di_1, 0, 1, 1, 1)
        self.s2_di_2 = QtWidgets.QDial(self.gridLayoutWidget_3)
        self.s2_di_2.setMaximum(9)
        self.s2_di_2.setPageStep(9)
        self.s2_di_2.setWrapping(False)
        self.s2_di_2.setNotchesVisible(True)
        self.s2_di_2.setObjectName("s2_di_2")
        self.gridLayout_3.addWidget(self.s2_di_2, 1, 1, 1, 1)
        self.s2_lb_1 = QtWidgets.QLabel(self.gridLayoutWidget_3)
        self.s2_lb_1.setObjectName("s2_lb_1")
        self.gridLayout_3.addWidget(self.s2_lb_1, 0, 0, 1, 1)
        self.s2_bt_3 = QtWidgets.QPushButton(self.gridLayoutWidget_3)
        self.s2_bt_3.setObjectName("s2_bt_3")
        self.gridLayout_3.addWidget(self.s2_bt_3, 2, 1, 1, 1)
        self.s2_lb_3 = QtWidgets.QLabel(self.gridLayoutWidget_3)
        self.s2_lb_3.setObjectName("s2_lb_3")
        self.gridLayout_3.addWidget(self.s2_lb_3, 3, 0, 1, 2)
        self.groupBox_3 = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox_3.setGeometry(QtCore.QRect(10, 550, 281, 161))
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayoutWidget_4 = QtWidgets.QWidget(self.groupBox_3)
        self.gridLayoutWidget_4.setGeometry(QtCore.QRect(10, 20, 261, 131))
        self.gridLayoutWidget_4.setObjectName("gridLayoutWidget_4")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.gridLayoutWidget_4)
        self.gridLayout_4.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.s3_lb_3 = QtWidgets.QLabel(self.gridLayoutWidget_4)
        self.s3_lb_3.setObjectName("s3_lb_3")
        self.gridLayout_4.addWidget(self.s3_lb_3, 2, 0, 1, 1)
        self.s3_lb_1 = QtWidgets.QLabel(self.gridLayoutWidget_4)
        self.s3_lb_1.setObjectName("s3_lb_1")
        self.gridLayout_4.addWidget(self.s3_lb_1, 0, 0, 1, 1)
        self.s3_lb_2 = QtWidgets.QLabel(self.gridLayoutWidget_4)
        self.s3_lb_2.setObjectName("s3_lb_2")
        self.gridLayout_4.addWidget(self.s3_lb_2, 1, 0, 1, 1)
        self.s3_line_3 = QtWidgets.QLineEdit(self.gridLayoutWidget_4)
        self.s3_line_3.setObjectName("s3_line_3")
        self.gridLayout_4.addWidget(self.s3_line_3, 2, 1, 1, 1)
        self.s3_line_2 = QtWidgets.QLineEdit(self.gridLayoutWidget_4)
        self.s3_line_2.setObjectName("s3_line_2")
        self.gridLayout_4.addWidget(self.s3_line_2, 1, 1, 1, 1)
        self.s3_line_1 = QtWidgets.QLineEdit(self.gridLayoutWidget_4)
        self.s3_line_1.setObjectName("s3_line_1")
        self.gridLayout_4.addWidget(self.s3_line_1, 0, 1, 1, 1)
        self.gridLayoutWidget = QtWidgets.QWidget(self.centralwidget)
        self.gridLayoutWidget.setGeometry(QtCore.QRect(600, 560, 381, 151))
        self.gridLayoutWidget.setObjectName("gridLayoutWidget")
        self.gridLayout = QtWidgets.QGridLayout(self.gridLayoutWidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.s4_lb_3 = QtWidgets.QLabel(self.gridLayoutWidget)
        self.s4_lb_3.setObjectName("s4_lb_3")
        self.gridLayout.addWidget(self.s4_lb_3, 2, 0, 1, 1)
        self.s4_line_3 = QtWidgets.QLineEdit(self.gridLayoutWidget)
        self.s4_line_3.setObjectName("s4_line_3")
        self.gridLayout.addWidget(self.s4_line_3, 2, 1, 1, 1)
        self.s4_line_1 = QtWidgets.QLCDNumber(self.gridLayoutWidget)
        self.s4_line_1.setObjectName("s4_line_1")
        self.gridLayout.addWidget(self.s4_line_1, 0, 1, 1, 1)
        self.s4_line_2 = QtWidgets.QLCDNumber(self.gridLayoutWidget)
        self.s4_line_2.setObjectName("s4_line_2")
        self.gridLayout.addWidget(self.s4_line_2, 1, 1, 1, 1)
        self.s4_lb_1 = QtWidgets.QLabel(self.gridLayoutWidget)
        self.s4_lb_1.setObjectName("s4_lb_1")
        self.gridLayout.addWidget(self.s4_lb_1, 0, 0, 1, 1)
        self.s4_lb_2 = QtWidgets.QLabel(self.gridLayoutWidget)
        self.s4_lb_2.setObjectName("s4_lb_2")
        self.gridLayout.addWidget(self.s4_lb_2, 1, 0, 1, 1)
        self.groupBox_4 = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox_4.setGeometry(QtCore.QRect(290, 550, 301, 161))
        self.groupBox_4.setObjectName("groupBox_4")
        self.raw_broswer = QtWidgets.QTextBrowser(self.groupBox_4)
        self.raw_broswer.setGeometry(QtCore.QRect(20, 20, 271, 131))
        self.raw_broswer.setObjectName("raw_broswer")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1024, 25))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        self.view_tab.setCurrentIndex(1)
        self.s1_bt_5.clicked.connect(self.bt_save_data.toggle)
        self.s1_bt_6.clicked.connect(self.bt_save_data.toggle)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.lb_photo.setText(_translate("MainWindow", "放攝影機畫面"))
        self.lb_select_cam.setText(_translate("MainWindow", "選擇攝影機"))
        self.bt_cam.setItemText(0, _translate("MainWindow", "默認攝影機(0)"))
        self.bt_cam.setItemText(1, _translate("MainWindow", "攝影機(1)"))
        self.bt_cam_start.setText(_translate("MainWindow", "開啟攝影"))
        self.bt_cam_stop.setText(_translate("MainWindow", "暫停攝影"))
        self.view_tab.setTabText(self.view_tab.indexOf(self.camara_tab), _translate("MainWindow", "攝影機資料"))
        self.lb_thers_set.setText(_translate("MainWindow", "設置參考線"))
        self.bt_thers_set.setItemText(0, _translate("MainWindow", "250"))
        self.bt_thers_set.setItemText(1, _translate("MainWindow", "500"))
        self.bt_thers_set.setItemText(2, _translate("MainWindow", "1000"))
        self.bt_thers_set.setItemText(3, _translate("MainWindow", "1500"))
        self.bt_thers_set.setItemText(4, _translate("MainWindow", "2000"))
        self.bt_thers_set.setItemText(5, _translate("MainWindow", "2500"))
        self.bt_thers_set.setItemText(6, _translate("MainWindow", "3000"))
        self.bt_thers_set.setItemText(7, _translate("MainWindow", "3500"))
        self.bt_thers_set.setItemText(8, _translate("MainWindow", "4000"))
        self.bt_start_draw.setText(_translate("MainWindow", "開啟繪製"))
        self.bt_stop_draw.setText(_translate("MainWindow", "暫停繪製"))
        self.bt_save_data.setText(_translate("MainWindow", "存取當前資料"))
        self.view_tab.setTabText(self.view_tab.indexOf(self.plot_tab), _translate("MainWindow", "原始圖表"))
        self.groupBox.setTitle(_translate("MainWindow", "裝置設定"))
        self.s1_lb_3.setText(_translate("MainWindow", "當前裝置"))
        self.s1_lb_2.setText(_translate("MainWindow", "USB Serial"))
        self.s1_lb_4.setText(_translate("MainWindow", "裝置類型"))
        self.s1_lb_1.setText(_translate("MainWindow", "檢查裝置"))
        self.s1_bt_1.setText(_translate("MainWindow", "檢查裝置"))
        self.s1_bt_5.setText(_translate("MainWindow", "start"))
        self.s1_bt_6.setText(_translate("MainWindow", "pause"))
        self.s1_bt_4.setItemText(0, _translate("MainWindow", "XMC1302"))
        self.s1_bt_4.setItemText(1, _translate("MainWindow", "microbit"))
        self.s1_bt_4.setItemText(2, _translate("MainWindow", "stm32 MAG"))
        self.groupBox_2.setTitle(_translate("MainWindow", "回控設定"))
        self.s2_lb_2.setText(_translate("MainWindow", "最大閥值"))
        self.s2_lb_1.setText(_translate("MainWindow", "最小閥值"))
        self.s2_bt_3.setText(_translate("MainWindow", "Send"))
        self.s2_lb_3.setText(_translate("MainWindow", "設置參數"))
        self.groupBox_3.setTitle(_translate("MainWindow", "系統資訊"))
        self.s3_lb_3.setText(_translate("MainWindow", "使用者"))
        self.s3_lb_1.setText(_translate("MainWindow", "開啟時間"))
        self.s3_lb_2.setText(_translate("MainWindow", "當前時間"))
        self.s3_line_3.setText(_translate("MainWindow", "關佳德"))
        self.s4_lb_3.setText(_translate("MainWindow", "當前狀態"))
        self.s4_lb_1.setText(_translate("MainWindow", "當前速度"))
        self.s4_lb_2.setText(_translate("MainWindow", "Duppler Freq"))
        self.groupBox_4.setTitle(_translate("MainWindow", "原始輸入"))

from pyqtgraph import GraphicsLayoutWidget



from setuptools import setup

setup(name='mLab-Doppler-Radar-Tool',
      version='0.1.5.2',
      packages=['mLab_DopplerRadar'],
      install_requires=[
          'pyserial','pyqtgraph'
      ],
      include_package_data=True,
      url='', license='MIT',
      author='Alex Kuan',
      author_email='agathakuannew@gmail.com',
      description='mLab Doppler Radar UART tool and example code')